@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-__version__ = "0.2.5"
+__version__ = "0.3.1"
 
 import secrets
 import configparser
@@ -35,6 +35,9 @@ parser.add_argument(
     ),
     action="store_true",
 )
+parser.add_argument(
+    "-i", "--install", help="attempt to install a system service.", action="store_true"
+)
 
 args, leftovers = parser.parse_known_args()
 
@@ -66,14 +69,15 @@ if data_dir.exists() is False or (data_dir / "config.ini").exists() is False:
 else:
     config_path = data_dir / "config.ini"
 
-config = configparser.RawConfigParser()
-config.read(config_path)
+
+temp_config = configparser.RawConfigParser()
+temp_config.read(config_path)
 
 
 def create_log(name):
     log = logging.getLogger(name)
     handler = logging.StreamHandler(sys.stdout)
-    if config.getboolean("ui", "debug"):
+    if temp_config.getboolean("ui", "debug"):
         log.setLevel(logging.DEBUG)
         handler.setLevel(logging.DEBUG)
     else:
@@ -88,6 +92,63 @@ def create_log(name):
 
 
 log = create_log("main")
+
+
+def load_config(config_path, data_dir):
+    config = configparser.RawConfigParser()
+    config.read(config_path)
+    global log
+    for key in config["files"]:
+        if config["files"][key] == "":
+            if key != "custom_css":
+                log.debug(f"Using default {key}")
+                config["files"][key] = str(data_dir / (key + ".json"))
+
+    for key in ["user_configuration", "user_displayprefs"]:
+        if key not in config["files"]:
+            log.debug(f"Using default {key}")
+            config["files"][key] = str(data_dir / (key + ".json"))
+
+    if "no_username" not in config["email"]:
+        config["email"]["no_username"] = "false"
+        log.debug("Set no_username to false")
+    if (
+        "email_html" not in config["password_resets"]
+        or config["password_resets"]["email_html"] == ""
+    ):
+        log.debug("Using default password reset email HTML template")
+        config["password_resets"]["email_html"] = str(local_dir / "email.html")
+    if (
+        "email_text" not in config["password_resets"]
+        or config["password_resets"]["email_text"] == ""
+    ):
+        log.debug("Using default password reset email plaintext template")
+        config["password_resets"]["email_text"] = str(local_dir / "email.txt")
+
+    if (
+        "email_html" not in config["invite_emails"]
+        or config["invite_emails"]["email_html"] == ""
+    ):
+        log.debug("Using default invite email HTML template")
+        config["invite_emails"]["email_html"] = str(local_dir / "invite-email.html")
+    if (
+        "email_text" not in config["invite_emails"]
+        or config["invite_emails"]["email_text"] == ""
+    ):
+        log.debug("Using default invite email plaintext template")
+        config["invite_emails"]["email_text"] = str(local_dir / "invite-email.txt")
+    if (
+        "public_server" not in config["jellyfin"]
+        or config["jellyfin"]["public_server"] == ""
+    ):
+        config["jellyfin"]["public_server"] = config["jellyfin"]["server"]
+    if "bs5" not in config["ui"] or config["ui"]["bs5"] == "":
+        config["ui"]["bs5"] = "false"
+    return config
+
+
+config = load_config(config_path, data_dir)
+
 web_log = create_log("waitress")
 if not first_run:
     email_log = create_log("emails")
@@ -100,20 +161,6 @@ if args.port is not None:
     log.debug(f"Using specified port {args.port}")
     config["ui"]["port"] = args.port
 
-for key in config["files"]:
-    if config["files"][key] == "":
-        if key != "custom_css":
-            log.debug(f"Using default {key}")
-            config["files"][key] = str(data_dir / (key + ".json"))
-
-for key in ["user_configuration", "user_displayprefs"]:
-    if key not in config["files"]:
-        log.debug(f"Using default {key}")
-        config["files"][key] = str(data_dir / (key + ".json"))
-
-if "no_username" not in config["email"]:
-    config["email"]["no_username"] = "false"
-    log.debug("Set no_username to false")
 
 try:
     with open(config["files"]["invites"], "r") as f:
@@ -140,69 +187,45 @@ data_store = JSONStorage(
     config["files"]["user_configuration"],
 )
 
-
-def default_css():
-    css = {}
-    css[
-        "href"
-    ] = "https://stackpath.bootstrapcdn.com/bootstrap/4.4.1/css/bootstrap.min.css"
-    css[
-        "integrity"
-    ] = "sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh"
-    css["crossorigin"] = "anonymous"
-    return css
+if config.getboolean("ui", "bs5"):
+    css_file = "bs5-jf.css"
+    log.debug("Using Bootstrap 5")
+else:
+    css_file = "bs4-jf.css"
 
 
-css = {}
-css = default_css()
-if "custom_css" in config["files"]:
+with open(config_base_path, "r") as f:
+    themes = json.load(f)["ui"]["theme"]
+
+theme_options = themes["options"]
+
+if "theme" not in config["ui"] or config["ui"]["theme"] not in theme_options:
+    config["ui"]["theme"] = themes["value"]
+
+if config.getboolean("ui", "bs5"):
+    num = 5
+else:
+    num = 4
+
+current_theme = config["ui"]["theme"]
+
+if "Bootstrap" in current_theme:
+    css_file = f"bs{num}.css"
+elif "Jellyfin" in current_theme:
+    css_file = f"bs{num}-jf.css"
+elif "Custom" in current_theme and "custom_css" in config["files"]:
     if config["files"]["custom_css"] != "":
         try:
-            shutil.copy(
-                config["files"]["custom_css"], (local_dir / "static" / "bootstrap.css")
-            )
-            log.debug("Loaded custom CSS")
-            css["href"] = "/bootstrap.css"
-            css["integrity"] = ""
-            css["crossorigin"] = ""
+            css_path = Path(config["files"]["custom_css"])
+            shutil.copy(css_path, (local_dir / "static" / css_path.name))
+            log.debug('Loaded custom CSS "{css_path.name}"')
+            css_file = css_path.name
         except FileNotFoundError:
             log.error(
                 f'Custom CSS {config["files"]["custom_css"]} not found, using default.'
             )
 
 
-if (
-    "email_html" not in config["password_resets"]
-    or config["password_resets"]["email_html"] == ""
-):
-    log.debug("Using default password reset email HTML template")
-    config["password_resets"]["email_html"] = str(local_dir / "email.html")
-if (
-    "email_text" not in config["password_resets"]
-    or config["password_resets"]["email_text"] == ""
-):
-    log.debug("Using default password reset email plaintext template")
-    config["password_resets"]["email_text"] = str(local_dir / "email.txt")
-
-if (
-    "email_html" not in config["invite_emails"]
-    or config["invite_emails"]["email_html"] == ""
-):
-    log.debug("Using default invite email HTML template")
-    config["invite_emails"]["email_html"] = str(local_dir / "invite-email.html")
-if (
-    "email_text" not in config["invite_emails"]
-    or config["invite_emails"]["email_text"] == ""
-):
-    log.debug("Using default invite email plaintext template")
-    config["invite_emails"]["email_text"] = str(local_dir / "invite-email.txt")
-if (
-    "public_server" not in config["jellyfin"]
-    or config["jellyfin"]["public_server"] == ""
-):
-    config["jellyfin"]["public_server"] = config["jellyfin"]["server"]
-
-
 def resp(success=True, code=500):
     if success:
         r = jsonify({"success": True})
@@ -217,7 +240,29 @@ def resp(success=True, code=500):
 
 
 def main():
-    if args.get_defaults:
+    if args.install:
+        executable = sys.argv[0]
+        print(f'Assuming executable path "{executable}".')
+        options = ["systemd"]
+        for i, opt in enumerate(options):
+            print(f"{i+1}: {opt}")
+        success = False
+        while not success:
+            try:
+                method = options[int(input(">: ")) - 1]
+                success = True
+            except IndexError:
+                pass
+        if method == "systemd":
+            with open(local_dir / "services" / "jf-accounts.service", "r") as f:
+                data = f.read()
+                data = data.replace("{executable}", executable)
+            service_path = str(Path("jf-accounts.service").resolve())
+            with open(service_path, "w") as f:
+                f.write(data)
+            print(f"service written to the current directory\n({service_path}).")
+            print("Place this in the appropriate directory, and reload daemons.")
+    elif args.get_defaults:
         import json
         from jellyfin_accounts.jf_api import Jellyfin
 
